@@ -28,7 +28,7 @@
 #include <gtk/gtk.h>
 
 /* Must be before all other gnome includes!! */
-#include "gnome-i18nP.h"
+#include <glib/gi18n-lib.h>
 
 #include <libgnomeui/gnome-stock-icons.h>
 #include "pixmaps/gnome-stock-pixbufs.h"
